# PWNlink
Passwords in the clear? Good luck with your router!

Based off ExploitDB ID: `33520`

## Installation
To install PWNlink, make sure `python3.7` and `python3-pip` are installed on your computer, then run:
```
pip3 install pwnlink
```

PWNlink is now installed!

## Usage
PWNlink can automatically find a router when run. If you want to specify an IP address instead, pass it as an argument to the `pwnlink` command. Everything else is automatic.